
%%%%%%%%%%%%%%%%%%%%%%%%%%%
%            2-D  grafika
%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%   Elementarni X-Y grafovi

% plot - linearni crtez
% loglog - logaritamsko-logaritamski crtez
% semilogx - linearno-logaritamski crtez
% semilogy - logaritamsko-linearni crtez
% polar - crtez u polarnim koordinatama
% plotyy - graf sa y oznakama na lijevo i na desno


%%%%%%%%%%%%%%%%%
%%%               plot, plotyy
%%%%%%%%%%%%%%%%

help plot

% PRIMJER 1

x=0:pi/100:2*pi;
y1=sin(x);
y2=cos(x);
plot(x,y1,'b-',x,y2,'r:');    % na istoj slici dva plota: y1(x) nacrtan plavom punom linjom (opcija 'b-') 
                                        % i y2(x) nacrtain tockasom crvenom linijom (opcija 'r:')  


% PRIMJER 2

 x = -pi:pi/10:pi;
 y = tan(sin(x)) - sin(tan(x));
 plot(x,y,'--rs',...                        % crtnaka (--) crvena linija (r), tocke su oznacene kvadratima (s)
     'LineWidth',2,...                   % debiljina linija je 2
     'MarkerEdgeColor','k',...     % boja rubova kvadrata je crna
     'MarkerFaceColor','g',...      % kvadrati su ispunjeni zelenom bojom
      'MarkerSize',10)                  % velicina kvadrata je 10

 x = -pi:pi/10000:pi;
 y = tan(sin(x)) - sin(tan(x));
 plot(x,y)

  
% PRIMJER 3
%  neradba plotyy ima y oznakame na lijevo i na desno  
  
x=1:0.1:7;
y1=exp(x);
y2=exp(-x.^2);
plotyy(x,y1,x,y2,'semilogy');   % opcija semilog znaci da ce y koordinata biti u logaritamskom mjerilu
grid on                                     % naredba za crtanje mreze na grafu
  
  
% PRIMJER 4

% jedan od nacina za crtanje dva razilicita grafa na istoj slici je
% koristenjem naredbe "hold on".

figure(100)    % "otvorimo" sliku pod rednim brojem 100
x=0:0.05:2*pi;
plot(x,sin(x),'b','LineWidth',2);

hold on            % na" kazemo da zelimo sljedeci graf 
                         % nacrtati na istoj slici koja je trenutno
                         % aktivna, a tordebom "hold on je slika 100
plot(x,cos(x),'r','LineWidth',4);
grid on
hold off
plot([1,2],[-0.5,0.5])


%%%%%%
% Neke opcije:
%%%%%%

% axis - kontrolira umjeravanje osi i njihovo pojavljivanje
% zoom - zoom-ira (uve?avanje i smanjivanje) 2-D crtea
% grid - linije mree
% box - okvir na osima
% axes - tvori osi u bilo kojim pozicijama
% subplot - tvori osi u (n x m) podgrafovima


% PRIMJER 5

help subplot
help axis

close all  % zatvori sve otvorene slike (ako takvih ima)

x=0:pi/100:2*pi;
y=sin(x);
subplot(2,1,1);           % slike ce biti podjeljena u dva redka i jedan stupac, a sad crtamo prvu sliku 
plot(x,y,'r');
axis([0 2*pi -0.7 0.7])  % osi ove slike idu od 0 do 2*pi po x-u, i od -0.7 do 0.7 po y
subplot(2,1,2)           % slika je podjeljena u dva redka i jedan stupac, a sad crtamo drugu sliku
plot(x,y,'b');
axis([-pi,3*pi,-1.1,1.1])

% PRIMJER 6

close all

x=0:pi/100:2*pi;
y1=sin(x); y2=cos(x);
y3=x.^2; y4=sqrt(x);

figure(1)
subplot(2,2,1)    % graf u prvom redku prvom stupcu
plot(x,y1,'r')

subplot(2,2,2)   % graf u prvom redku drugom stupcu
plot(x,y2,'r:')

subplot(2,2,3)  % graf u drugom redku prvom stupcu
plot(x,y3,'b')

subplot(2,2,4)  % graf u drugom redku drugom stupcu
plot(x,y4,'b:')

%%%%
% Oznacivanje grafova:

% legend - legenda grafa
% title - naslov grafa
% xlabel - oznaka (opis) X-osi
% ylabel - oznaka (opis) Y-axis
% text - oznaka teksta
% gtext - postavljanje teksta misem

clf;       % izbrise trenutnu sliku (odnosno "handle" slike)
x=0:pi/100:2*pi;
y1=sin(x);
y2=cos(x);
plot(x,y1,'b',x,y2,'r');
legend('Sinus','Kosinus');    % legenda (objasnjenje) za razlicite krivulje/grafove na slici
xlabel('vrijeme');         % naziv x osi
ylabel('funkcija');         % naziv y osi
title('Trigonometrija je zabavna');    % naslov slike
text(4, 0.5,'Tekst na (4,0.5)');           % stavlja tekst na definirane koordinate u slici
grid on


%%%%%%%%%%%%%%%%%
%%%               ploar
%%%%%%%%%%%%%%%%

% crta polarni graf

help polar

% PRIMJER

theta=0:pi/100:2*pi;
rho=sin(theta*4);
polar(theta,rho,'g');
  

%%%%%%%%%%%%%%%%%%%%%%%%%%%
%            3-D  grafika
%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Elementarni 3-D crtezi:

% plot3 - crta linije i tocke u 3-D prostoru
% mesh - 3-D mesh (resetkasta) povrsina
% surf - 3-D obojena povrsina
% fill3 - 3-D povrsina prekrivena poligonima

% PRIMJER 1: naredba meshgrid

help meshgrid

x=[1,2,3];
y=[4,5];
[xm,ym]=meshgrid(x,y)


% PRIMJER 2

x=[-2:0.1:2];
y=[-2:0.1:2];
[X,Y]=meshgrid(x,y);
Z=X .* exp(-X.^2 - Y.^2);

plot3(X,Y,Z), grid        % izvedite i provjerite rezultat

mesh(X,Y,Z)                % izvedite i provjerite rezultat

meshc(X,Y,Z)               % izvedite i provjerite rezultat

meshz(X,Y,Z)                % izvedite i provjerite rezultat

waterfall(X,Y,Z), view([10 35])    % izvedite i provjerite rezultat

surf(X,Y,Z)    % izvedite i provjerite rezultat


% PRIMJER 3

t = 0:pi/50:20*pi;
plot3(sin(t),cos(t),t,'LineWidth',3);
grid on


% PRIMJER 4

[X,Y] = meshgrid(-2:.4:2, -2:.4:2);
Z = sin(X).* sin(Y).*exp(-X.^2 - Y.^2);
mesh(X,Y,Z)

% PRIMJER 5

[X,Y] = meshgrid(-2:.4:2, -2:.4:2);
Z = sin(X).* sin(Y).*exp(-X.^2 - Y.^2);
surf(X,Y,Z)

%%%%%%%%%%%

% Boje

% colormap - Tablica boja
% caxis - Pseudocolor umjeravanje (scaling) osi
% shading - mod osjen?avanja bojom
% hidden - brisanje skrivenih linija u reetki
% brighten - osvjetljavanje ili zatamnjenje tablice boja

% Mape boja

% hsv - Hue-saturation-value color map.
% hot - Black-red-yellow-white color map.
% gray - Linear gray-scale color map.
% bone - Gray-scale with tinge of blue color map.
% copper - Linear copper-tone color map.
% pink - Pastel shades of pink color map.
% white - All white color map.
% flag - Alternating red, white, blue, and black color map.
% lines - Color map with the line colors.
% colorcube - Enhanced color-cube color map.
% jet - Variant of HSV.
% prism - Prism color map.
% cool - Shades of cyan and magenta color map.
% autumn - Shades of red and yellow color map.
% spring - Shades of magenta and yellow color map.
% winter - Shades of blue and green color map.
% summer - Shades of green and yellow color map.



% PRIMJER

[X,Y] = meshgrid(-2:.2:2, -2:.2:2);
Z = sin(X).* sin(Y).* ...
exp(-X.^2 - Y.^2);
surf(X,Y,Z)
colormap(hot(15))
shading interp


% PRIMJER

figure(2)
[X,Y] = meshgrid(-2:.2:2, -2:.2:2);
Z = sin(X).* sin(Y).* ...
exp(-X.^2 - Y.^2);
surf(X,Y,Z)
colormap(hot(15))
shading interp
caxis([0.05 0.2])


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%               Specijalizirani 2-D grafovi
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% area - crtez ispunjene povrsine
% bar - bar graf
% barh - horizontalni bar graf
% bar3 - 3-D bar graf
% bar3h - horizontal 3-D bar graf
% comet - kometu slicna trajektorija
% errorbar - 'error bar' crtez
% ezplot - jednostavno funkcijsko crtalo
% feather - feather crtez
% fill - ispunjeni 2-D poligoni
% fplot - function plot
% hist - histogram.
% pareto - pareto crtez
% pie - krika (Pie) crtez
% pie3 - 3-D krika crtez
% plotmatrix - scatter plot matrix.
% ribbon - crta 2-D linije kao vrpce u 3-D.
% stem - disketni niz ili "stem" crtez
% stairs - stepeni?asti crtez

% PRIMJER

X=93:1:98;
Y=[1 2 3;
4 5 4;
2 3 4;
3 6 5;
1 2 4;
2 3 2 ];
bar3(X,Y)


% PRIMJER

x = 1:10;
y = 100*rand(10,1);
e = sqrt(y);
errorbar(x,y,e)


% PRIMJER

yn=randn(100000,1);
x=min(yn):0.1:max(yn);
hist(yn,x);

% PRIMJER

ezplot('sin(x)')


% PRIMJER

fplot('sin(x)', [-pi pi])

% PRIMJER

pie([1 1 2])
pie3([1 1 2 10])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                      Konturni grafovi
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% contour - konturni crtez
% contourf - ispunjeni konturni crtez
% contour3 - 3-D konturni crtez
% clabel - konturni crtez s oznakama visina
% pcolor - Pseudocolor (sahovnica, checkerboard) crtez
% quiver - quiver crtez
% voronoi - Voronoi dijagrami


% PRIMJER

[X,Y] = meshgrid(-2:.2:2, -2:.2:2);
Z = sin(X).* sin(Y).*exp(-X.*X - Y.*Y);
[fx,fy] = gradient(Z);
contour(X,Y,Z,10)
hold on
quiver(X,Y,fx,fy);
hold off

% PRIMJER

[X,Y] = meshgrid(-2:.2:2, -2:.2:2);
Z = sin(X).* sin(Y).*exp(-X.*X - Y.*Y);
[fx,fy] = gradient(Z);
[cs,h]=contourf(X,Y,Z,10);
clabel(cs,h);


% PRIMJER

[X,Y] = meshgrid(-2:.2:2, -2:.2:2);
Z = sin(X).* sin(Y).*exp(-X.*X - Y.*Y);
contour3(X,Y,Z,20);


%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%    Specializirani 3-D crtezi
%%%%%%%%%%%%%%%%%%%%%%%%%%

% comet3 - 3-D comet-like trajectories.
% meshc - Combination mesh/contour plot.
% meshz - 3-D mesh with curtain.
% stem3 - 3-D stem plot.
% quiver3 - 3-D quiver plot.
% slice - Volumetric slice plot.
% surfc - Combination surf/contour plot.
% trisurf - Triangular surface plot.
% trimesh - Triangular mesh plot.
% waterfall - Waterfall plot.


% PRIMJER

[x,y,z] = meshgrid(-2:.2:2, -2:.25:2, -2:.16:2);
v = x .* exp(-x.^2 - y.^2 - z.^2);
slice(x,y,z,v,[0,1], 0, 0)


% PRIMJER

[X,Y] = meshgrid(-2:.2:2, -2:.2:2);
Z = sin(X).* sin(Y).* ...
exp(-X.*X - Y.*Y);
waterfall(X,Y,Z);







