# Snaga R-a lezi takodjer u njegovoj dobro razvijenoj 
# grafici u vise znacajnih grafickih paketa (qplot,lattice, grid, ggplot2), 
# a poseban razvitak krece prema graifci na WEBu (googleVis paket).

#################################################################
# Graficki izlaz u nacelu ide na graficki uredaj 
# (najcesce zaslon racunala). Medutim to se moze promijeniti pozivom 
# funkcija za spremanje grafova na neki drugi uredaj ili u datoteku 
# razlicitog formata (npr. pdf(), png(), jpeg(), bmp(), win.metafile() i dr.).
# Zatvaranje nakon iscrtavanja, tako zadanog grafickog izlaza 
# postize se funkcijom dev.off().

# Zelimo li graficki izlaz dobiti na primjer u PDF formatu, 
# pozvat cemo dvije naredbe, izmedjukojih cemo smjestiti naredbe za crtanje:

#pdf('ime_izlazne_datoteke_.pdf')
## graficke naredbe 
#dev.off()
##################################################################

# Osnovna funkcija za crtanje grafova je plot() funkcija:

plot(-10:10, (-10:10)^3)
plot(-10:10, (-10:10)^3, type="l")   # linije (lines)
plot(-10:10, (-10:10)^3, type="p")   # tocke (points)
plot(-10:10, (-10:10)^3, type="b")   # oboje (both)
plot(-10:10, (-10:10)^3, type="h")   # histogram
plot(-10:10, (-10:10)^3, type="s")   # stepenasto (stairs)
plot(-10:10, (-10:10)^3, type="n")   # bez plotanja (no plot)

# Funkcija plot() moze se kombinirati s drugim grafickim funkcijama 
# (npr. abline() funkcijom za crtanje pravca):

# crta jednostavni crtez kao pozadinu
plot(x = c(0, 10), y = c(0, 10))
# crta horizontalnu liniju na y=4
abline(h = 4)
# crta vertikalnu liniju na x=3
abline(v = 3)
# crta liniju y=ax + b sa y-odsjeckom od 1 i nagibom od 1
abline(a = 1, b = 1)
# crta liniju y=ax + b sa y-odsjeckom od 10 i nagibom od -1, preko coef
# argumenta:
abline(coef = c(10, -1))

################

# Funkcija plot() moze se prosirivati argumentima za oznake osi, 
# naslova i slicno. 
# Na graf se moze dodati i tekst s pomocu text() funkcije, 
# u kojoj se s argumentom 'col' definira boja upisanog teksta:

plot(-1:1, -1:1, type = "n", xlab = "Re", ylab = "Im")
K <- 16
text(0,0,'centar')
text(0.5,0.5,'gore-desno')
text(-0.5,0,'lijevo')
text(exp((0+1i) * 2 * pi * (1:K)/K), col = 2)

################

# Promjena nekog grafickog parametra ostvaruje se preko par() 
# funkcije, ili kao dio neke naredbe za crtanje. 

help("par")

# U sljedecoj tablici navedeni su neki od parametara, 
# a slikom su opisani znakovi i vrste linija:

# Parametar   Opis
# col 	    boja
# col.main 	boja za naslove
# col.sub 	boja za podnaslove
# col.lab 	boja za oznake
# col.axis 	boja za tekstove uz osi
# fg 	      boja crteza (forground)
# bg 	      boja pozadine (background)
# cex 	    skaliranje teksta (1.5 je 50% veci), 0.5 je 50% manji)
# cex.main 	skaliranje naslova
# pch 	    vrsta markera/oznaka tocaka u grafovima
# lty 	    vrsta linija
----- 	-----

# "Parametri markera i linija"

# Na primjer, promjenu boje pozadine u zutu, dobit ce se ovako:

par(bg = "yellow")
plot(c(1, 9), 1:2, type = "n")
# crtanje poligona na zadanim koordinatama
polygon(1:9, c(2, 1, 2, 1, 1.2, 2, 1, 2, 1.5), density = c(10, 20), angle = c(-45, 
    45))
title(main = "Grafika u R-u", sub = "Poligon")  
  
################

par(bg="gray",fg="blue",xlog="x",ylog="sin(x)")
x<-seq(0,pi,0.1)
plot(x,sin(x),type="b",lwd=3)
plot(x,sin(x),type="l",lwd=5)

########################  
########################

# funkcija barplot()

help("barplot")

# primjer 1
par(bg="white",fg="black")
barplot(c(3,2,1,2,0))

# primjer 2
M<-matrix(c(1,2,3,3,2,1,2,1,2),nrow=3,ncol=3,byrow=TRUE)
barplot(M)

# primjer 3
barplot(M,beside=TRUE)

# primjer 4
barplot(height = cbind(x = c(465, 91) / 465 * 100,
                       y = c(840, 200) / 840 * 100,
                       z = c(37, 17) / 37 * 100),
        beside = FALSE,
        width = c(465, 840, 37),
        col = c(1, 2),
        legend.text = c("A", "B"),
        args.legend = list(x = "topleft"))


#######################

# jos primjera
# funkcija dotchart

help("dotchart")

## primjer 1

dotchart(c(1,2,3,4,5,4,1))

dotchart(c(1,1,1,2,2,2,3,3,3,1,1,1))

## primjer 2

x <- mtcars[order(mtcars$mpg), ]
x$cyl <- factor(x$cyl)
x$color[x$cyl == 4] <- "red"
x$color[x$cyl == 6] <- "blue"
x$color[x$cyl == 8] <- "darkgreen"
dotchart(x$mpg, labels = row.names(x), cex = 0.7, groups = x$cyl, gcolor = "black", 
    color = x$color, pch = 19, main = "Potrosnja goriva za modele automobila\ngroupirane po broju cilindara (4, 6 i 8)", 
    xlab = "Predene milje po galonu nafte")



  

